/* eslint-disable @next/next/no-img-element */
import { capitalizeFirstLetter } from "@/common/string-utils";
import { SkinPart } from "mcutils-library";
import Link from "next/link";
import { ReactElement } from "react";
import { Button } from "../ui/button";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "../ui/dialog";
import { Tooltip, TooltipContent, TooltipTrigger } from "../ui/tooltip";

type SkinPartImageProps = {
  /**
   * The player's name.
   */
  playerName: string;

  /**
   * The skin part.
   */
  part: SkinPart;

  /**
   * The URL to the skin part.
   */
  url: string;

  /**
   * The size to display the skin part.
   */
  size?: number;
};

export function SkinPartImage({ playerName, part, url, size = 64 }: SkinPartImageProps): ReactElement {
  const partName = capitalizeFirstLetter(part);

  return (
    <Tooltip>
      <TooltipTrigger>
        <Dialog>
          <DialogTrigger asChild>
            <img className={`h-[${size}px]`} src={url} alt={`The player's ${part}`} loading="lazy" />
          </DialogTrigger>
          <DialogContent className="w-fit min-w-72 h-fit">
            <DialogHeader>
              <DialogTitle>
                {playerName}&apos;s {partName}
              </DialogTitle>
              <DialogDescription>See the skin part below.</DialogDescription>
            </DialogHeader>
            <div className="flex items-center flex-col w-full">
              <img className="h-[256px]" src={url} alt={`The player's ${partName}`} loading="lazy" />
            </div>
            <DialogFooter>
              <Link href={url}>
                <Button>Open in new tab</Button>
              </Link>
            </DialogFooter>
          </DialogContent>
        </Dialog>
      </TooltipTrigger>
      <TooltipContent>
        <p>
          Click to view {playerName}&apos;s {partName}
        </p>
      </TooltipContent>
    </Tooltip>
  );
}
